@@ -1,18 +1,28 @@
 """Asynchronous Python client for BSBLAN."""
 
 from .bsblan import BSBLAN, BSBLANConfig
-from .exceptions import BSBLANConnectionError, BSBLANError
-from .models import Device, HotWaterState, Info, Sensor, State, StaticState
+from .exceptions import BSBLANAuthError, BSBLANConnectionError, BSBLANError
+from .models import (
+    Device,
+    DHWTimeSwitchPrograms,
+    HotWaterState,
+    Info,
+    Sensor,
+    State,
+    StaticState,
+)
 
 __all__ = [
     "BSBLAN",
+    "BSBLANAuthError",
     "BSBLANConfig",
     "BSBLANConnectionError",
     "BSBLANError",
-    "Info",
-    "State",
+    "DHWTimeSwitchPrograms",
     "Device",
-    "Sensor",
-    "StaticState",
     "HotWaterState",
+    "Info",
+    "Sensor",
+    "State",
+    "StaticState",
 ]
