@@ -5,7 +5,10 @@ from __future__ import annotations
 import asyncio
 import logging
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, Any, Literal, Mapping, cast
+from typing import TYPE_CHECKING, Any, Literal, cast
+
+if TYPE_CHECKING:
+    from collections.abc import Mapping
 
 import aiohttp
 from aiohttp.hdrs import METH_POST
@@ -29,17 +32,27 @@ from .constants import (
     APIConfig,
 )
 from .exceptions import (
+    BSBLANAuthError,
     BSBLANConnectionError,
     BSBLANError,
     BSBLANInvalidParameterError,
     BSBLANVersionError,
 )
-from .models import Device, HotWaterState, Info, Sensor, State, StaticState
+from .models import (
+    Device,
+    DHWTimeSwitchPrograms,
+    HotWaterState,
+    Info,
+    Sensor,
+    State,
+    StaticState,
+)
 from .utility import APIValidator
 
 if TYPE_CHECKING:
+    from typing import Self
+
     from aiohttp.client import ClientSession
-    from typing_extensions import Self
 
 SectionLiteral = Literal["heating", "staticValues", "device", "sensor", "hot_water"]
 
@@ -200,6 +213,9 @@ class BSBLAN:
         version = pkg_version.parse(self._firmware_version)
         if version < pkg_version.parse("1.2.0"):
             self._api_version = "v1"
+        elif version >= pkg_version.parse("5.0.0"):
+            # BSB-LAN 5.0+ has breaking changes but uses v3-compatible API
+            self._api_version = "v3"
         elif version >= pkg_version.parse("3.0.0"):
             self._api_version = "v3"
         else:
@@ -298,14 +314,51 @@ class BSBLAN:
                     headers=headers,
                 ) as response:
                     response.raise_for_status()
-                    return cast(dict[str, Any], await response.json())
-        except asyncio.TimeoutError as e:
+                    response_data = cast("dict[str, Any]", await response.json())
+                    return self._process_response(response_data, base_path)
+        except TimeoutError as e:
             raise BSBLANConnectionError(BSBLANConnectionError.message_timeout) from e
+        except aiohttp.ClientResponseError as e:
+            if e.status in (401, 403):
+                raise BSBLANAuthError from e
+            raise BSBLANConnectionError(BSBLANConnectionError.message_error) from e
         except aiohttp.ClientError as e:
             raise BSBLANConnectionError(BSBLANConnectionError.message_error) from e
         except ValueError as e:
             raise BSBLANError(str(e)) from e
 
+    def _process_response(
+        self, response_data: dict[str, Any], base_path: str
+    ) -> dict[str, Any]:
+        """Process response data based on firmware version.
+
+        BSB-LAN 5.0+ includes additional 'payload' field in /JQ responses
+        that needs to be handled for compatibility.
+
+        Args:
+            response_data: Raw response data from BSB-LAN
+            base_path: The API endpoint that was called
+
+        Returns:
+            Processed response data compatible with existing code
+
+        """
+        # For non-JQ endpoints, return response as-is
+        if base_path != "/JQ":
+            return response_data
+
+        # Check if we have a firmware version to determine processing
+        if not self._firmware_version:
+            return response_data
+
+        # For BSB-LAN 5.0+, remove 'payload' field if present as it's for debugging
+        version = pkg_version.parse(self._firmware_version)
+        if version >= pkg_version.parse("5.0.0") and "payload" in response_data:
+            # Remove payload field if present - it's added for debugging in 5.0+
+            return {k: v for k, v in response_data.items() if k != "payload"}
+
+        return response_data
+
     def _build_url(self, base_path: str) -> URL:
         """Build the URL for the request.
 
@@ -553,23 +606,75 @@ class BSBLAN:
         data = dict(zip(params["list"], list(data.values()), strict=True))
         return HotWaterState.from_dict(data)
 
-    async def set_hot_water(
+    async def set_hot_water(  # noqa: PLR0913
         self,
         nominal_setpoint: float | None = None,
         reduced_setpoint: float | None = None,
         operating_mode: str | None = None,
-    ) -> None:
+        dhw_time_programs: DHWTimeSwitchPrograms | None = None,
+        eco_mode_selection: str | None = None,
+        dhw_charging_priority: str | None = None,
+        legionella_dwelling_time: float | None = None,
+        legionella_circulation_pump: str | None = None,
+        legionella_circulation_temp_diff: float | None = None,
+        dhw_circulation_pump_release: str | None = None,
+        dhw_circulation_pump_cycling: float | None = None,
+        dhw_circulation_setpoint: float | None = None,
+        operating_mode_changeover: str | None = None,
+    ) -> None:  # pylint: disable=too-many-arguments,too-many-positional-arguments,too-many-locals
         """Change the state of the hot water system through BSB-Lan.
 
         Args:
             nominal_setpoint (float | None): The nominal setpoint temperature to set.
             reduced_setpoint (float | None): The reduced setpoint temperature to set.
+            operating_mode (str | None): The operating mode to set.
+            dhw_time_programs (DHWTimeSwitchPrograms | None): Time switch programs.
+            eco_mode_selection (str | None): Eco mode selection.
+            dhw_charging_priority (str | None): DHW charging priority.
+            legionella_dwelling_time (float | None): Legionella dwelling time.
+            legionella_circulation_pump (str | None): Legionella circulation pump.
+            legionella_circulation_temp_diff (float | None): Legionella circulation
+                temperature difference.
+            dhw_circulation_pump_release (str | None): DHW circulation pump release.
+            dhw_circulation_pump_cycling (float | None): DHW circulation pump cycling.
+            dhw_circulation_setpoint (float | None): DHW circulation setpoint.
+            operating_mode_changeover (str | None): Operating mode changeover.
 
         """
+        # Validate only one parameter is being set
+        time_program_params = []
+        if dhw_time_programs:
+            if dhw_time_programs.monday:
+                time_program_params.append(dhw_time_programs.monday)
+            if dhw_time_programs.tuesday:
+                time_program_params.append(dhw_time_programs.tuesday)
+            if dhw_time_programs.wednesday:
+                time_program_params.append(dhw_time_programs.wednesday)
+            if dhw_time_programs.thursday:
+                time_program_params.append(dhw_time_programs.thursday)
+            if dhw_time_programs.friday:
+                time_program_params.append(dhw_time_programs.friday)
+            if dhw_time_programs.saturday:
+                time_program_params.append(dhw_time_programs.saturday)
+            if dhw_time_programs.sunday:
+                time_program_params.append(dhw_time_programs.sunday)
+            if dhw_time_programs.standard_values:
+                time_program_params.append(dhw_time_programs.standard_values)
+
         self._validate_single_parameter(
             nominal_setpoint,
             reduced_setpoint,
             operating_mode,
+            eco_mode_selection,
+            dhw_charging_priority,
+            legionella_dwelling_time,
+            legionella_circulation_pump,
+            legionella_circulation_temp_diff,
+            dhw_circulation_pump_release,
+            dhw_circulation_pump_cycling,
+            dhw_circulation_setpoint,
+            operating_mode_changeover,
+            *time_program_params,
             error_msg=MULTI_PARAMETER_ERROR_MSG,
         )
 
@@ -577,20 +682,52 @@ class BSBLAN:
             nominal_setpoint,
             reduced_setpoint,
             operating_mode,
+            dhw_time_programs,
+            eco_mode_selection,
+            dhw_charging_priority,
+            legionella_dwelling_time,
+            legionella_circulation_pump,
+            legionella_circulation_temp_diff,
+            dhw_circulation_pump_release,
+            dhw_circulation_pump_cycling,
+            dhw_circulation_setpoint,
+            operating_mode_changeover,
         )
         await self._set_hot_water_state(state)
 
-    def _prepare_hot_water_state(
+    def _prepare_hot_water_state(  # noqa: PLR0913, PLR0912
         self,
         nominal_setpoint: float | None,
         reduced_setpoint: float | None,
         operating_mode: str | None,
-    ) -> dict[str, Any]:
+        dhw_time_programs: DHWTimeSwitchPrograms | None = None,
+        eco_mode_selection: str | None = None,
+        dhw_charging_priority: str | None = None,
+        legionella_dwelling_time: float | None = None,
+        legionella_circulation_pump: str | None = None,
+        legionella_circulation_temp_diff: float | None = None,
+        dhw_circulation_pump_release: str | None = None,
+        dhw_circulation_pump_cycling: float | None = None,
+        dhw_circulation_setpoint: float | None = None,
+        operating_mode_changeover: str | None = None,
+    ) -> dict[str, Any]:  # pylint: disable=too-many-arguments,too-many-positional-arguments,too-many-locals,too-many-branches
         """Prepare the hot water state for setting.
 
         Args:
             nominal_setpoint (float | None): The nominal setpoint temperature to set.
             reduced_setpoint (float | None): The reduced setpoint temperature to set.
+            operating_mode (str | None): The operating mode to set.
+            dhw_time_programs (DHWTimeSwitchPrograms | None): Time switch programs.
+            eco_mode_selection (str | None): Eco mode selection.
+            dhw_charging_priority (str | None): DHW charging priority.
+            legionella_dwelling_time (float | None): Legionella dwelling time.
+            legionella_circulation_pump (str | None): Legionella circulation pump.
+            legionella_circulation_temp_diff (float | None): Legionella circulation
+                temperature difference.
+            dhw_circulation_pump_release (str | None): DHW circulation pump release.
+            dhw_circulation_pump_cycling (float | None): DHW circulation pump cycling.
+            dhw_circulation_setpoint (float | None): DHW circulation setpoint.
+            operating_mode_changeover (str | None): Operating mode changeover.
 
         Returns:
             dict[str, Any]: The prepared state for the hot water.
@@ -616,6 +753,95 @@ class BSBLAN:
                     "Type": "1",
                 },
             )
+        if eco_mode_selection is not None:
+            state.update(
+                {
+                    "Parameter": "1601",
+                    "EnumValue": eco_mode_selection,
+                    "Type": "1",
+                },
+            )
+        if dhw_charging_priority is not None:
+            state.update(
+                {
+                    "Parameter": "1630",
+                    "EnumValue": dhw_charging_priority,
+                    "Type": "1",
+                },
+            )
+        if legionella_dwelling_time is not None:
+            state.update(
+                {
+                    "Parameter": "1646",
+                    "Value": str(legionella_dwelling_time),
+                    "Type": "1",
+                },
+            )
+        if legionella_circulation_pump is not None:
+            state.update(
+                {
+                    "Parameter": "1647",
+                    "EnumValue": legionella_circulation_pump,
+                    "Type": "1",
+                },
+            )
+        if legionella_circulation_temp_diff is not None:
+            state.update(
+                {
+                    "Parameter": "1648",
+                    "Value": str(legionella_circulation_temp_diff),
+                    "Type": "1",
+                },
+            )
+        if dhw_circulation_pump_release is not None:
+            state.update(
+                {
+                    "Parameter": "1660",
+                    "EnumValue": dhw_circulation_pump_release,
+                    "Type": "1",
+                },
+            )
+        if dhw_circulation_pump_cycling is not None:
+            state.update(
+                {
+                    "Parameter": "1661",
+                    "Value": str(dhw_circulation_pump_cycling),
+                    "Type": "1",
+                },
+            )
+        if dhw_circulation_setpoint is not None:
+            state.update(
+                {
+                    "Parameter": "1663",
+                    "Value": str(dhw_circulation_setpoint),
+                    "Type": "1",
+                },
+            )
+        if operating_mode_changeover is not None:
+            state.update(
+                {
+                    "Parameter": "1680",
+                    "EnumValue": operating_mode_changeover,
+                    "Type": "1",
+                },
+            )
+
+        if dhw_time_programs:
+            time_program_mapping = {
+                "561": dhw_time_programs.monday,
+                "562": dhw_time_programs.tuesday,
+                "563": dhw_time_programs.wednesday,
+                "564": dhw_time_programs.thursday,
+                "565": dhw_time_programs.friday,
+                "566": dhw_time_programs.saturday,
+                "567": dhw_time_programs.sunday,
+                "576": dhw_time_programs.standard_values,
+            }
+
+            for param, value in time_program_mapping.items():
+                if value is not None:
+                    state.update({"Parameter": param, "Value": value, "Type": "1"})
+
         if not state:
             raise BSBLANError(NO_STATE_ERROR_MSG)
         return state
