@@ -51,17 +51,34 @@ API_V1: Final[APIConfig] = {
     },
     "hot_water": {
         "1600": "operating_mode",
+        "1601": "eco_mode_selection",
         "1610": "nominal_setpoint",
         "1614": "nominal_setpoint_max",
         "1612": "reduced_setpoint",
         "1620": "release",
+        "1630": "dhw_charging_priority",
         "1640": "legionella_function",
         "1645": "legionella_setpoint",
         "1641": "legionella_periodicity",
         "1642": "legionella_function_day",
         "1643": "legionella_function_time",
+        "1646": "legionella_dwelling_time",
+        "1647": "legionella_circulation_pump",
+        "1648": "legionella_circulation_temp_diff",
+        "1660": "dhw_circulation_pump_release",
+        "1661": "dhw_circulation_pump_cycling",
+        "1663": "dhw_circulation_setpoint",
+        "1680": "operating_mode_changeover",
         "8830": "dhw_actual_value_top_temperature",
         "8820": "state_dhw_pump",
+        "561": "dhw_time_program_monday",
+        "562": "dhw_time_program_tuesday",
+        "563": "dhw_time_program_wednesday",
+        "564": "dhw_time_program_thursday",
+        "565": "dhw_time_program_friday",
+        "566": "dhw_time_program_saturday",
+        "567": "dhw_time_program_sunday",
+        "576": "dhw_time_program_standard_values",
     },
 }
 
@@ -90,17 +107,34 @@ API_V3: Final[APIConfig] = {
     },
     "hot_water": {
         "1600": "operating_mode",
+        "1601": "eco_mode_selection",
         "1610": "nominal_setpoint",
         "1614": "nominal_setpoint_max",
         "1612": "reduced_setpoint",
         "1620": "release",
+        "1630": "dhw_charging_priority",
         "1640": "legionella_function",
         "1645": "legionella_setpoint",
         "1641": "legionella_periodicity",
         "1642": "legionella_function_day",
         "1644": "legionella_function_time",
+        "1646": "legionella_dwelling_time",
+        "1647": "legionella_circulation_pump",
+        "1648": "legionella_circulation_temp_diff",
+        "1660": "dhw_circulation_pump_release",
+        "1661": "dhw_circulation_pump_cycling",
+        "1663": "dhw_circulation_setpoint",
+        "1680": "operating_mode_changeover",
         "8830": "dhw_actual_value_top_temperature",
         "8820": "state_dhw_pump",
+        "561": "dhw_time_program_monday",
+        "562": "dhw_time_program_tuesday",
+        "563": "dhw_time_program_wednesday",
+        "564": "dhw_time_program_thursday",
+        "565": "dhw_time_program_friday",
+        "566": "dhw_time_program_saturday",
+        "567": "dhw_time_program_sunday",
+        "576": "dhw_time_program_standard_values",
     },
 }
 
