@@ -14,6 +14,20 @@ from mashumaro.mixins.json import DataClassJSONMixin
 from bsblan.constants import TEMPERATURE_UNITS
 
 
+@dataclass
+class DHWTimeSwitchPrograms:
+    """Dataclass for DHW time switch programs."""
+
+    monday: str | None = None
+    tuesday: str | None = None
+    wednesday: str | None = None
+    thursday: str | None = None
+    friday: str | None = None
+    saturday: str | None = None
+    sunday: str | None = None
+    standard_values: str | None = None
+
+
 class DataType(IntEnum):
     """Enumeration of BSB-LAN data types."""
 
@@ -163,21 +177,38 @@ class Sensor(DataClassJSONMixin):
 
 
 @dataclass
-class HotWaterState(DataClassJSONMixin):
+class HotWaterState(DataClassJSONMixin):  # pylint: disable=too-many-instance-attributes
     """Object holds info about object for hot water climate."""
 
     operating_mode: EntityInfo | None = None
+    eco_mode_selection: EntityInfo | None = None
     nominal_setpoint: EntityInfo | None = None
     nominal_setpoint_max: EntityInfo | None = None
     reduced_setpoint: EntityInfo | None = None
     release: EntityInfo | None = None
+    dhw_charging_priority: EntityInfo | None = None
     legionella_function: EntityInfo | None = None
     legionella_setpoint: EntityInfo | None = None
     legionella_periodicity: EntityInfo | None = None
     legionella_function_day: EntityInfo | None = None
     legionella_function_time: EntityInfo | None = None
+    legionella_dwelling_time: EntityInfo | None = None
+    legionella_circulation_pump: EntityInfo | None = None
+    legionella_circulation_temp_diff: EntityInfo | None = None
+    dhw_circulation_pump_release: EntityInfo | None = None
+    dhw_circulation_pump_cycling: EntityInfo | None = None
+    dhw_circulation_setpoint: EntityInfo | None = None
+    operating_mode_changeover: EntityInfo | None = None
     dhw_actual_value_top_temperature: EntityInfo | None = None
     state_dhw_pump: EntityInfo | None = None
+    dhw_time_program_monday: EntityInfo | None = None
+    dhw_time_program_tuesday: EntityInfo | None = None
+    dhw_time_program_wednesday: EntityInfo | None = None
+    dhw_time_program_thursday: EntityInfo | None = None
+    dhw_time_program_friday: EntityInfo | None = None
+    dhw_time_program_saturday: EntityInfo | None = None
+    dhw_time_program_sunday: EntityInfo | None = None
+    dhw_time_program_standard_values: EntityInfo | None = None
 
 
 @dataclass
